==> kde4edu_3.93.0.orig.tar.gz: kdeedu-3.93.0/kalgebra/src/dictionary.h <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef DICTIONARY_H
#define DICTIONARY_H

#include <QTreeView>

/**
	@author 
*/
class Dictionary : public QTreeView
{
Q_OBJECT
	public:
		Dictionary(QWidget *p=0);
		virtual ~Dictionary(){}
};

#endif

==> kde4edu_3.94.0.orig.tar.gz: kdeedu-3.94.0/kalgebra/src/dictionary.h <==
/*************************************************************************************
 *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#ifndef DICTIONARY_H
#define DICTIONARY_H

#include <QWidget>

class QLabel;
class QListView;
class QModelIndex;
class OperatorsModel;
/**
	@author Aleix Pol
*/
class Dictionary : public QWidget
{
Q_OBJECT
	public:
		Dictionary(QWidget *p=0);
		virtual ~Dictionary(){}
		
	private slots:
		void activated(const QModelIndex& );
		
	private:
		QLabel *m_name;
		QLabel *m_descr;
		QLabel *m_example;
		QListView *m_list;
		OperatorsModel *m_ops;
};

#endif
